# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`gpfs`](#gpfs): base GPFS class
* [`gpfs::ces`](#gpfs--ces): GPFS CES class
* [`gpfs::client`](#gpfs--client): GPFS client class
* [`gpfs::gui`](#gpfs--gui): GPFS GUI class
* [`gpfs::server`](#gpfs--server): GPFS server class

#### Private Classes

* `gpfs::ces::config`: Manage GPFS CES config
* `gpfs::ces::install`: Manage GPFS CES install
* `gpfs::client::config`: Manage GPFS client config
* `gpfs::client::install`: Manage GPFS client install
* `gpfs::gui::config`: Manage GPFS GUI config
* `gpfs::gui::install`: Manage GPFS GUI install
* `gpfs::gui::service`: Manage GPFS GUI services
* `gpfs::install`: Manage GPFS installs
* `gpfs::repo`: Manage GPFS repo
* `gpfs::server::config`: Manage GPFS NSD config
* `gpfs::server::install`: Manage GPFS NSD install

### Defined types

* [`gpfs::client::rkm`](#gpfs--client--rkm): Manage GPFS client ISKLM configuration

### Resource types

* [`gpfs_audit`](#gpfs_audit): Manage a GPFS filesystem audit
* [`gpfs_config`](#gpfs_config): GPFS config
* [`gpfs_fileset`](#gpfs_fileset): Manage a GPFS fileset
* [`gpfs_fileset_quota`](#gpfs_fileset_quota): Set a GPFS fileset quota
* [`scalemgmt_config`](#scalemgmt_config): scalemgmt config
* [`scalemgmt_conn_validator`](#scalemgmt_conn_validator): Verify that a connection can be successfully established between a node and the scalemgmt server.  Its primary use is as a precondition to pr

## Classes

### <a name="gpfs"></a>`gpfs`

base GPFS class

#### Examples

##### 

```puppet
include ::gpfs
```

#### Parameters

The following parameters are available in the `gpfs` class:

* [`manage_repo`](#-gpfs--manage_repo)
* [`repo_baseurl`](#-gpfs--repo_baseurl)
* [`manage_packages`](#-gpfs--manage_packages)
* [`package_ensure`](#-gpfs--package_ensure)
* [`packages`](#-gpfs--packages)
* [`config_filesystems`](#-gpfs--config_filesystems)

##### <a name="-gpfs--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Sets if GPFS repo should be managed

Default value: `true`

##### <a name="-gpfs--repo_baseurl"></a>`repo_baseurl`

Data type: `Optional[String]`

The GPFS repo baseurl

Default value: `undef`

##### <a name="-gpfs--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS packages should be managed

Default value: `true`

##### <a name="-gpfs--package_ensure"></a>`package_ensure`

Data type: `String`

GPFS package ensure property

Default value: `'present'`

##### <a name="-gpfs--packages"></a>`packages`

Data type: `Array`

GPFS base packages

Default value:

```puppet
[
    "gpfs.gplbin-${facts['kernelrelease']}",
    'gpfs.adv',
    'gpfs.base',
    'gpfs.crypto',
    'gpfs.docs',
    'gpfs.ext',
    'gpfs.gpl',
    'gpfs.gskit',
    'gpfs.msg.en_US',
  ]
```

##### <a name="-gpfs--config_filesystems"></a>`config_filesystems`

Data type: `Optional[Array]`

Filesystems where filesets are managed by Puppet

Default value: `undef`

### <a name="gpfs--ces"></a>`gpfs::ces`

GPFS CES class

#### Examples

##### 

```puppet
include ::gpfs::ces
```

#### Parameters

The following parameters are available in the `gpfs::ces` class:

* [`manage_packages`](#-gpfs--ces--manage_packages)
* [`package_ensure`](#-gpfs--ces--package_ensure)
* [`packages`](#-gpfs--ces--packages)

##### <a name="-gpfs--ces--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS CES packages should be managed

Default value: `true`

##### <a name="-gpfs--ces--package_ensure"></a>`package_ensure`

Data type: `String`

GPFS CES package ensure property

Default value: `'present'`

##### <a name="-gpfs--ces--packages"></a>`packages`

Data type: `Array`

GPFS CES packages

Default value:

```puppet
[
    'gpfs.java',
    'gpfs.smb',
    'nfs-ganesha',
    'nfs-ganesha-gpfs',
    'nfs-ganesha-utils',
  ]
```

### <a name="gpfs--client"></a>`gpfs::client`

GPFS client class

#### Examples

##### 

```puppet
include ::gpfs::client
```

#### Parameters

The following parameters are available in the `gpfs::client` class:

* [`manage_packages`](#-gpfs--client--manage_packages)
* [`package_ensure`](#-gpfs--client--package_ensure)
* [`packages`](#-gpfs--client--packages)
* [`manage_service_files`](#-gpfs--client--manage_service_files)
* [`manage_ssh_authorized_keys`](#-gpfs--client--manage_ssh_authorized_keys)
* [`ssh_user`](#-gpfs--client--ssh_user)
* [`ssh_authorized_keys`](#-gpfs--client--ssh_authorized_keys)
* [`rkms`](#-gpfs--client--rkms)
* [`bin_paths`](#-gpfs--client--bin_paths)

##### <a name="-gpfs--client--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS client packages should be managed

Default value: `true`

##### <a name="-gpfs--client--package_ensure"></a>`package_ensure`

Data type: `String[1]`

GPFS client package ensure property

Default value: `'present'`

##### <a name="-gpfs--client--packages"></a>`packages`

Data type: `Array[String[1]]`

GPFS client packages

Default value: `[]`

##### <a name="-gpfs--client--manage_service_files"></a>`manage_service_files`

Data type: `Boolean`

Determines if GPFS service files are managed

Default value: `true`

##### <a name="-gpfs--client--manage_ssh_authorized_keys"></a>`manage_ssh_authorized_keys`

Data type: `Boolean`

Determines if SSH authorized_keys should be managed

Default value: `true`

##### <a name="-gpfs--client--ssh_user"></a>`ssh_user`

Data type: `String[1]`

SSH user for GPFS

Default value: `'root'`

##### <a name="-gpfs--client--ssh_authorized_keys"></a>`ssh_authorized_keys`

Data type: `Hash`

SSH authorized keys for NSDs

Default value: `{}`

##### <a name="-gpfs--client--rkms"></a>`rkms`

Data type: `Hash`

Hash to define gpfs::client::rkm resources

Default value: `{}`

##### <a name="-gpfs--client--bin_paths"></a>`bin_paths`

Data type: `Array[Stdlib::Absolutepath]`

Paths to add to PATH

Default value: `[]`

### <a name="gpfs--gui"></a>`gpfs::gui`

GPFS GUI class

#### Examples

##### 

```puppet
include ::gpfs::gui
```

#### Parameters

The following parameters are available in the `gpfs::gui` class:

* [`manage_packages`](#-gpfs--gui--manage_packages)
* [`package_ensure`](#-gpfs--gui--package_ensure)
* [`packages`](#-gpfs--gui--packages)
* [`manage_firewall`](#-gpfs--gui--manage_firewall)
* [`firewall_source`](#-gpfs--gui--firewall_source)
* [`firewall_https_only`](#-gpfs--gui--firewall_https_only)
* [`manage_services`](#-gpfs--gui--manage_services)
* [`manage_initgui`](#-gpfs--gui--manage_initgui)

##### <a name="-gpfs--gui--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS GUI packages should be managed

Default value: `true`

##### <a name="-gpfs--gui--package_ensure"></a>`package_ensure`

Data type: `String`

GPFS GUI package ensure property

Default value: `'present'`

##### <a name="-gpfs--gui--packages"></a>`packages`

Data type: `Array`

GPFS GUI packages

Default value:

```puppet
[
    'gpfs.gui',
  ]
```

##### <a name="-gpfs--gui--manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Determines if firewall should be managed

Default value: `true`

##### <a name="-gpfs--gui--firewall_source"></a>`firewall_source`

Data type: `Optional[Variant[String, Array, Boolean]]`

Firewall source value

Default value: `undef`

##### <a name="-gpfs--gui--firewall_https_only"></a>`firewall_https_only`

Data type: `Boolean`

Only manage firewall rules for HTTPS

Default value: `false`

##### <a name="-gpfs--gui--manage_services"></a>`manage_services`

Data type: `Boolean`

Determines if services are managed

Default value: `true`

##### <a name="-gpfs--gui--manage_initgui"></a>`manage_initgui`

Data type: `Boolean`

Determines if manage Exec to initialize GUI

Default value: `true`

### <a name="gpfs--server"></a>`gpfs::server`

GPFS server class

#### Examples

##### 

```puppet
include ::gpfs::server
```

#### Parameters

The following parameters are available in the `gpfs::server` class:

* [`manage_packages`](#-gpfs--server--manage_packages)
* [`package_ensure`](#-gpfs--server--package_ensure)
* [`packages`](#-gpfs--server--packages)
* [`bin_paths`](#-gpfs--server--bin_paths)

##### <a name="-gpfs--server--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Determines if GPFS server packages should be managed

Default value: `true`

##### <a name="-gpfs--server--package_ensure"></a>`package_ensure`

Data type: `String`

GPFS server package ensure property

Default value: `'present'`

##### <a name="-gpfs--server--packages"></a>`packages`

Data type: `Array`

GPFS server packages

Default value: `[]`

##### <a name="-gpfs--server--bin_paths"></a>`bin_paths`

Data type: `Array[Stdlib::Absolutepath]`

Paths to add to PATH

Default value: `['/usr/lpp/mmfs/bin']`

## Defined types

### <a name="gpfs--client--rkm"></a>`gpfs::client::rkm`

Manage GPFS client ISKLM configuration

#### Parameters

The following parameters are available in the `gpfs::client::rkm` defined type:

* [`rkm_id`](#-gpfs--client--rkm--rkm_id)
* [`type`](#-gpfs--client--rkm--type)
* [`kmip_server_uris`](#-gpfs--client--rkm--kmip_server_uris)
* [`key_store`](#-gpfs--client--rkm--key_store)
* [`key_store_source`](#-gpfs--client--rkm--key_store_source)
* [`passphrase`](#-gpfs--client--rkm--passphrase)
* [`client_cert_label`](#-gpfs--client--rkm--client_cert_label)
* [`tenant_name`](#-gpfs--client--rkm--tenant_name)
* [`connection_timeout`](#-gpfs--client--rkm--connection_timeout)
* [`connection_attempts`](#-gpfs--client--rkm--connection_attempts)
* [`retry_sleep`](#-gpfs--client--rkm--retry_sleep)
* [`order`](#-gpfs--client--rkm--order)

##### <a name="-gpfs--client--rkm--rkm_id"></a>`rkm_id`

Data type: `String[1]`



Default value: `$name`

##### <a name="-gpfs--client--rkm--type"></a>`type`

Data type: `String[1]`



Default value: `'ISKLM'`

##### <a name="-gpfs--client--rkm--kmip_server_uris"></a>`kmip_server_uris`

Data type: `Array`



Default value: `[]`

##### <a name="-gpfs--client--rkm--key_store"></a>`key_store`

Data type: `Stdlib::Absolutepath`



Default value: `'/var/mmfs/etc/RKMcerts/ISKLM.proj2'`

##### <a name="-gpfs--client--rkm--key_store_source"></a>`key_store_source`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-gpfs--client--rkm--passphrase"></a>`passphrase`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-gpfs--client--rkm--client_cert_label"></a>`client_cert_label`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-gpfs--client--rkm--tenant_name"></a>`tenant_name`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-gpfs--client--rkm--connection_timeout"></a>`connection_timeout`

Data type: `String[1]`



Default value: `'5'`

##### <a name="-gpfs--client--rkm--connection_attempts"></a>`connection_attempts`

Data type: `String[1]`



Default value: `'3'`

##### <a name="-gpfs--client--rkm--retry_sleep"></a>`retry_sleep`

Data type: `String[1]`



Default value: `'50000'`

##### <a name="-gpfs--client--rkm--order"></a>`order`

Data type: `String[1]`



Default value: `'10'`

## Resource types

### <a name="gpfs_audit"></a>`gpfs_audit`

Manage a GPFS filesystem audit

#### Examples

##### Enable audit on `test` filesystem

```puppet
gpfs_audit { 'test':
  filesystem  => 'test',
  retention   => 25,
  filesets    => ['foo'],
}
```

#### Properties

The following properties are available in the `gpfs_audit` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `events`

Audit events

Default value: `['ALL']`

##### `filesets`

Filesets to audit

##### `skip_filesets`

Filesets to skip audit

#### Parameters

The following parameters are available in the `gpfs_audit` type.

* [`auto_disable`](#-gpfs_audit--auto_disable)
* [`compliant`](#-gpfs_audit--compliant)
* [`filesystem`](#-gpfs_audit--filesystem)
* [`log_fileset`](#-gpfs_audit--log_fileset)
* [`name`](#-gpfs_audit--name)
* [`provider`](#-gpfs_audit--provider)
* [`retention`](#-gpfs_audit--retention)

##### <a name="-gpfs_audit--auto_disable"></a>`auto_disable`

Valid values: `true`, `false`

Automatically disable filesets missing from `filesets` array

Default value: `false`

##### <a name="-gpfs_audit--compliant"></a>`compliant`

Valid values: `true`, `false`

Set audit fileset as compliant

Default value: `false`

##### <a name="-gpfs_audit--filesystem"></a>`filesystem`

The GPFS filesystem name.

##### <a name="-gpfs_audit--log_fileset"></a>`log_fileset`

The GPFS audit log fileset.

Default value: `.audit_log`

##### <a name="-gpfs_audit--name"></a>`name`

namevar

The default namevar.

##### <a name="-gpfs_audit--provider"></a>`provider`

The specific backend to use for this `gpfs_audit` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="-gpfs_audit--retention"></a>`retention`

The retention in days

Default value: `365`

### <a name="gpfs_config"></a>`gpfs_config`

GPFS config

#### Parameters

The following parameters are available in the `gpfs_config` type.

* [`filesystems`](#-gpfs_config--filesystems)
* [`name`](#-gpfs_config--name)

##### <a name="-gpfs_config--filesystems"></a>`filesystems`

Filesystems to manage

##### <a name="-gpfs_config--name"></a>`name`

namevar

GPFS config

### <a name="gpfs_fileset"></a>`gpfs_fileset`

Manage a GPFS fileset

#### Examples

##### Create `test` GPFS fileset

```puppet
gpfs_fileset { 'test':
  filesystem      => 'project',
  path            => '/gpfs/project/test',
  owner           => 'nobody:wheel',
  permissions     => '1770',
  inode_space     => 'new',
  max_num_inodes  => 1000000,
  alloc_inodes    => 1000000,
}
```

#### Properties

The following properties are available in the `gpfs_fileset` type.

##### `alloc_inodes`

Allocated inodes for fileset.

##### `ensure`

Valid values: `present`, `absent`, `unlinked`

The state of the fileset

Default value: `present`

##### `max_num_inodes`

Max number of inodes for fileset.

##### `owner`

Owner of GPFS fileset: user:group

##### `path`

The GPFS fileset path.

##### `permissions`

Permissions of fileset.

#### Parameters

The following parameters are available in the `gpfs_fileset` type.

* [`afm_attributes`](#-gpfs_fileset--afm_attributes)
* [`enforce_permissions`](#-gpfs_fileset--enforce_permissions)
* [`fileset`](#-gpfs_fileset--fileset)
* [`filesystem`](#-gpfs_fileset--filesystem)
* [`inode_space`](#-gpfs_fileset--inode_space)
* [`inode_tolerance`](#-gpfs_fileset--inode_tolerance)
* [`name`](#-gpfs_fileset--name)
* [`provider`](#-gpfs_fileset--provider)

##### <a name="-gpfs_fileset--afm_attributes"></a>`afm_attributes`

AFM attributes

##### <a name="-gpfs_fileset--enforce_permissions"></a>`enforce_permissions`

Valid values: `true`, `false`

Enforce POSIX permissions after creation

Default value: `false`

##### <a name="-gpfs_fileset--fileset"></a>`fileset`

The GPFS fileset name.

##### <a name="-gpfs_fileset--filesystem"></a>`filesystem`

The GPFS filesystem name.

##### <a name="-gpfs_fileset--inode_space"></a>`inode_space`

inodeSpace of fileset.

Default value: `new`

##### <a name="-gpfs_fileset--inode_tolerance"></a>`inode_tolerance`

Number of inodes to allow GPFS to adjust max or allocated inodes without triggering a Puppet change

Default value: `32`

##### <a name="-gpfs_fileset--name"></a>`name`

namevar

The default namevar.

##### <a name="-gpfs_fileset--provider"></a>`provider`

The specific backend to use for this `gpfs_fileset` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="gpfs_fileset_quota"></a>`gpfs_fileset_quota`

**Autorequires**:
  * `gpfs_fileset` - Puppet will autorequire the `gpfs_fileset` resource defined in `fileset` property.

#### Examples

##### Add fileset quota to `test` fileset.

```puppet
gpfs_fileset_quota { 'test':
  filesystem => 'project',
  block_soft_limit  => '5T',
  block_hard_limit  => '5T',
  files_soft_limit  => 1000000,
  files_hard_limit  => 1000000,
}
```

#### Properties

The following properties are available in the `gpfs_fileset_quota` type.

##### `block_hard_limit`

blockHardLimit of quota

##### `block_soft_limit`

blockSoftLimit of quota

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `files_hard_limit`

filesHardLimit of quota

##### `files_soft_limit`

filesSoftLimit of quota

#### Parameters

The following parameters are available in the `gpfs_fileset_quota` type.

* [`fileset`](#-gpfs_fileset_quota--fileset)
* [`filesystem`](#-gpfs_fileset_quota--filesystem)
* [`name`](#-gpfs_fileset_quota--name)
* [`object_name`](#-gpfs_fileset_quota--object_name)
* [`provider`](#-gpfs_fileset_quota--provider)
* [`type`](#-gpfs_fileset_quota--type)

##### <a name="-gpfs_fileset_quota--fileset"></a>`fileset`

The GPFS fileset name.

##### <a name="-gpfs_fileset_quota--filesystem"></a>`filesystem`

The GPFS filesystem name.

##### <a name="-gpfs_fileset_quota--name"></a>`name`

namevar

The default namevar

##### <a name="-gpfs_fileset_quota--object_name"></a>`object_name`

The GPFS quota object name

##### <a name="-gpfs_fileset_quota--provider"></a>`provider`

The specific backend to use for this `gpfs_fileset_quota` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-gpfs_fileset_quota--type"></a>`type`

Quota type

Default value: `fileset`

### <a name="scalemgmt_config"></a>`scalemgmt_config`

scalemgmt config

#### Parameters

The following parameters are available in the `scalemgmt_config` type.

* [`api_password`](#-scalemgmt_config--api_password)
* [`api_user`](#-scalemgmt_config--api_user)
* [`base_url`](#-scalemgmt_config--base_url)
* [`name`](#-scalemgmt_config--name)

##### <a name="-scalemgmt_config--api_password"></a>`api_password`

API password

Default value: `admin001`

##### <a name="-scalemgmt_config--api_user"></a>`api_user`

API user

Default value: `admin`

##### <a name="-scalemgmt_config--base_url"></a>`base_url`

Base URL of GPFS API

Default value: `https://localhost:443/scalemgmt/`

##### <a name="-scalemgmt_config--name"></a>`name`

namevar

scalemgmt config

### <a name="scalemgmt_conn_validator"></a>`scalemgmt_conn_validator`

Verify that a connection can be successfully established between a node
and the scalemgmt server.  Its primary use is as a precondition to
prevent configuration changes from being applied if the scalemgmt
server cannot be reached, but it could potentially be used for other
purposes such as monitoring.

#### Properties

The following properties are available in the `scalemgmt_conn_validator` type.

##### `ensure`

Valid values: `present`, `absent`

Ensure

Default value: `present`

#### Parameters

The following parameters are available in the `scalemgmt_conn_validator` type.

* [`api_password`](#-scalemgmt_conn_validator--api_password)
* [`api_user`](#-scalemgmt_conn_validator--api_user)
* [`name`](#-scalemgmt_conn_validator--name)
* [`provider`](#-scalemgmt_conn_validator--provider)
* [`scalemgmt_port`](#-scalemgmt_conn_validator--scalemgmt_port)
* [`scalemgmt_server`](#-scalemgmt_conn_validator--scalemgmt_server)
* [`test_url`](#-scalemgmt_conn_validator--test_url)
* [`timeout`](#-scalemgmt_conn_validator--timeout)

##### <a name="-scalemgmt_conn_validator--api_password"></a>`api_password`

API password

Default value: `admin001`

##### <a name="-scalemgmt_conn_validator--api_user"></a>`api_user`

API user name

Default value: `admin`

##### <a name="-scalemgmt_conn_validator--name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="-scalemgmt_conn_validator--provider"></a>`provider`

The specific backend to use for this `scalemgmt_conn_validator` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="-scalemgmt_conn_validator--scalemgmt_port"></a>`scalemgmt_port`

The port that the scalemgmt server should be listening on.

Default value: `443`

##### <a name="-scalemgmt_conn_validator--scalemgmt_server"></a>`scalemgmt_server`

The DNS name or IP address of the server where scalemgmt should be running.

Default value: `localhost`

##### <a name="-scalemgmt_conn_validator--test_url"></a>`test_url`

URL to use for testing if the scalemgmt API is up

Default value: `/scalemgmt/v2/info`

##### <a name="-scalemgmt_conn_validator--timeout"></a>`timeout`

The max number of seconds that the validator should wait before giving up and deciding that scalemgmt is not running;
defaults to 30 seconds.

Default value: `30`

